# This package depends on automagic byte compilation
# https://fedoraproject.org/wiki/Changes/No_more_automagic_Python_bytecompilation_phase_2
%global _python_bytecompile_extra 1

Name:           python-cherrypy
%global         camelname CherryPy
Version:        8.9.1
Release:        8%{?dist}
Summary:        Pythonic, object-oriented web development framework
License:        BSD
URL:            http://www.cherrypy.org/
Source0:        https://files.pythonhosted.org/packages/source/C/%{camelname}/%{camelname}-%{version}.tar.gz

BuildArch:      noarch
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
BuildRequires:  python3-setuptools_scm
BuildRequires:  dos2unix

# Extras
Requires: python3-pyOpenSSL
Requires: python3-simplejson
# Keeping these two as 'Recommends' because the version requirements aren't yet
# currently satisfied in Fedora
Requires: python3-routes >= 2.3.1
Requires: python3-memcached >= 1.58

# Test dependencies
BuildRequires:  python3-mock
BuildRequires:  python3-pytest
BuildRequires:  python3-coverage
BuildRequires:  python3-nose
BuildRequires:  python3-nose-testconfig

%global _description\
CherryPy allows developers to build web applications in much the same way\
they would build any other object-oriented Python program. This usually\
results in smaller source code developed in less time.

%description %_description

%package -n     python3-cherrypy
Summary:        %{summary}
%{?python_provide:%python_provide python3-cherrypy}
%description -n python3-cherrypy

%prep
%setup -q -n %{camelname}-%{version}

dos2unix cherrypy/tutorial/tutorial.conf

%build
%py3_build

%install
%py3_install

mv %{buildroot}%{_bindir}/cherryd %{buildroot}%{_bindir}/python%{python3_version}-cherryd
ln -s python%{python3_version}-cherryd %{buildroot}%{_bindir}/python3-cherryd

%check
LANG=C.utf-8 %{__python3} -m pytest --ignore=build --ignore=cherrypy/test/test_static.py

%files -n python3-cherrypy
%license LICENSE.md
%doc README.rst
%doc cherrypy/tutorial
%{_bindir}/python3-cherryd
%{_bindir}/python%{python3_version}-cherryd
%{python3_sitelib}/*
%exclude %{python3_sitelib}/cherrypy/cherryd
%exclude %{python3_sitelib}/cherrypy/test
%exclude %{python3_sitelib}/cherrypy/tutorial

%changelog
* Mon Feb 10 2020 Giulio Fidente <gfidente@redhatcom> - 8.9.1-8
- Skip test_null_bytes because python <= 3.7.6

* Fri Mar 15 2019 Ken Dreyer <kdreyer@redhat.com> - 8.9.1-7
- rename source package to python-cherrypy

* Sat Feb 02 2019 Fedora Release Engineering <releng@fedoraproject.org> - 8.9.1-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Sat Jul 14 2018 Fedora Release Engineering <releng@fedoraproject.org> - 8.9.1-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Tue Jun 19 2018 Miro Hrončok <mhroncok@redhat.com> - 8.9.1-4
- Rebuilt for Python 3.7

* Fri Feb 09 2018 Fedora Release Engineering <releng@fedoraproject.org> - 8.9.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 8.9.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Wed Feb 22 2017 Tomas Orsava <torsava@redhat.com> - 8.9.1-1
- Updated to 8.9.1 to solve a FTBFS (#1424123)

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 8.7.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Sun Jan 01 2017 Miro Hrončok <mhroncok@redhat.com> - 8.7.0-1
- Updated to 8.7.0 (#1409339)

* Wed Dec 28 2016 Miro Hrončok <mhroncok@redhat.com> - 8.6.0-1
- Updated to 8.6.0 (#1331982)
- Rebuild for Python 3.6

* Tue Jul 19 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 5.1.0-2
- https://fedoraproject.org/wiki/Changes/Automatic_Provides_for_Python_RPM_Packages

* Wed Mar 16 2016 Tomas Orsava <torsava@redhat.com> - 5.1.0-1
- Updated to a new version
- Patched a build test error in said new version

* Wed Mar 09 2016 Tomas Orsava <torsava@redhat.com> - 5.0.1-2
- Included a patch for the last issue when building against python 3.5
    (f24 or rawhide) based on an upstream commit:
    https://bitbucket.org/cyraxjoe/cherrypy/commits/3c0983f310777933a687d265601981d05025ff2e

* Thu Feb 25 2016 Tomas Orsava <torsava@redhat.com> - 5.0.1-1
- Updated to a new version
- Added one new build dependency
- Included a patch for the first of two test errors when building for rawhide
    (caused by changes in python 3.5) based on an upstream pull request:
    https://bitbucket.org/cherrypy/cherrypy/pull-requests/120/workaround-for-issue-1382-python-35

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 3.8.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Tue Nov 10 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.8.0-2
- Rebuilt for https://fedoraproject.org/wiki/Changes/python3.5

* Tue Jul 07 2015 Miro Hrončok <mhroncok@redhat.com> - 3.8.0-1
- Update to 3.8.0 (#1236248)

* Thu Jun 18 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.7.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sat Apr 25 2015 Fedora Release Monitoring <release-monitoring@fedoraproject.org> - 3.7.0-1
- Update to 3.7.0 (#1215290)

* Fri Sep 26 2014 Miro Hrončok <mhroncok@redhat.com> - 3.6.0-1
- New version 3.6.0 (#1100749)
- Skip more tests :(

* Sun Jun 08 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.2.6-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Fri May 16 2014 Matej Stuchlik <mstuchli@redhat.com> - 3.2.6-1
- Updated to 3.2.6

* Fri May 02 2014 Miro Hrončok <mhroncok@redhat.com> - 3.2.4-4
- Rebuilt for Python 3.4

* Wed Nov 13 2013 Miro Hrončok <mhroncok@redhat.com> - 3.2.4-3
- Delete tutorial's __pycache__ after %%install AND after %%check

* Tue Nov 12 2013 Miro Hrončok <mhroncok@redhat.com> - 3.2.4-2
- Use only %%{buildroot} and don't mix it with RPM_BUILD_ROOT

* Tue Nov 12 2013 Miro Hrončok <mhroncok@redhat.com> - 3.2.4-1
- Retaken orphaned package
- Update to 3.2.4
- Remove some deprecated statements form the spec
- Remove some patches
- Refactor %%check
- Add license to %%doc and remove it form site-packages

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.2.0-0.rc1.r2567.1.8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.2.0-0.rc1.r2567.1.7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Sat Aug 04 2012 David Malcolm <dmalcolm@redhat.com> - 3.2.0-0.rc1.r2567.1.6
- rebuild for https://fedoraproject.org/wiki/Features/Python_3.3

* Sat Jul 21 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.2.0-0.rc1.r2567.1.5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Sat Jan 14 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.2.0-0.rc1.r2567.1.4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Wed Feb 09 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.2.0-0.rc1.r2567.1.3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Wed Aug 25 2010 Thomas Spura <tomspur@fedoraproject.org> - 3.2.0-0.rc1.r2567.1.2
- rebuild with python3.2
  http://lists.fedoraproject.org/pipermail/devel/2010-August/141368.html

* Thu Jul 22 2010 David Malcolm <dmalcolm@redhat.com> - 3.2.0-0.rc1.r2567.1.1
- Rebuilt for https://fedoraproject.org/wiki/Features/Python_2.7/MassRebuild

* Mon Apr 19 2010 David Malcolm <dmalcolm@redhat.com> - 3.2.0-0.rc1.r2567.1
- disable a test that hangs when run under Koji (patch 1)

* Mon Apr  5 2010 David Malcolm <dmalcolm@redhat.com> - 3.2.0-0.rc1.r2567
- initial packaging for python 3, based on python-cherrypy-3.2.0-0.1.rc1.fc14

* Tue Feb 23 2010 Toshio Kuratomi <toshio@fedoraproject.org> - 3.2.0-0.1.rc1
- New upstream release candidate

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.1.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Tue Jun 16 2009 Toshio Kuratomi <toshio@fedoraproject.org> - 3.1.2-1
- New upstream with python-2.6 fixes.
- BR tidy for tests.

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.1.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Mon Dec 1 2008 Toshio Kuratomi <toshio@fedoraproject.org> - 3.1.1-1
- Update to 3.1.1
- Fix python-2.6 build errors
- Make test code non-interactive via cmdline switch
- Refresh the no test and tutorial patch

* Sat Nov 29 2008 Ignacio Vazquez-Abrams <ivazqueznet+rpm@gmail.com> - 3.0.3-3
- Rebuild for Python 2.6

* Tue Jan 22 2008 Toshio Kuratomi <toshio@fedoraproject.org> 3.0.3-2
- Forgot to upload the tarball.

* Mon Jan 21 2008 Toshio Kuratomi <toshio@fedoraproject.org> 3.0.3-1
- Upgrade to 3.0.3.

* Thu Jan 17 2008 Toshio Kuratomi <toshio@fedoraproject.org> 2.3.0-2
- EINTR Patch needed to be forwarded ported as well as it is only applied to
  CP trunk (3.x).

* Thu Jan 17 2008 Toshio Kuratomi <toshio@fedoraproject.org> 2.3.0-1
- Update to new upstream which rolls in the backported security fix.
- Refresh other patches to apply against new version.
- Change to new canonical source URL.
- Reenable tests.

* Sun Jan  6 2008 Toshio Kuratomi <toshio@fedoraproject.org> 2.2.1-8
- Fix a security bug with a backport of http://www.cherrypy.org/changeset/1775
- Include the egginfo files as well as the python files.

* Sat Nov  3 2007 Luke Macken <lmacken@redhat.com> 2.2.1-7
- Apply backported fix from http://www.cherrypy.org/changeset/1766
  to improve CherryPy's SIGSTOP/SIGCONT handling (Bug #364911).
  Thanks to Nils Philippsen for the patch.

* Mon Feb 19 2007 Luke Macken <lmacken@redhat.com> 2.2.1-6
- Disable regression tests until we can figure out why they
  are dying in mock.

* Sun Dec 10 2006 Luke Macken <lmacken@redhat.com> 2.2.1-5
- Add python-devel to BuildRequires

* Sun Dec 10 2006 Luke Macken <lmacken@redhat.com> 2.2.1-4
- Rebuild for python 2.5

* Mon Sep 18 2006 Luke Macken <lmacken@redhat.com> 2.2.1-3
- Rebuild for FC6
- Include pyo files instead of ghosting them

* Thu Jul 13 2006 Luke Macken <lmacken@redhat.com> 2.2.1-2
- Rebuild

* Thu Jul 13 2006 Luke Macken <lmacken@redhat.com> 2.2.1-1
- Update to 2.2.1
- Remove unnecessary python-abi requirement

* Sat Apr 22 2006 Gijs Hollestelle <gijs@gewis.nl> 2.2.0-1
- Update to 2.2.0

* Wed Feb 22 2006 Gijs Hollestelle <gijs@gewis.nl> 2.1.1-1
- Update to 2.1.1 (Security fix)

* Tue Nov  1 2005 Gijs Hollestelle <gijs@gewis.nl> 2.1.0-1
- Updated to 2.1.0

* Sat May 14 2005 Gijs Hollestelle <gijs@gewis.nl> 2.0.0-2
- Added dist tag

* Sun May  8 2005 Gijs Hollestelle <gijs@gewis.nl> 2.0.0-1
- Updated to 2.0.0 final
- Updated python-cherrypy-tutorial-doc.patch to match new version

* Wed Apr  6 2005 Ignacio Vazquez-Abrams <ivazquez@ivazquez.net> 2.0.0-0.2.b
- Removed CFLAGS

* Wed Mar 23 2005 Gijs Hollestelle <gijs[AT]gewis.nl> 2.0.0-0.1.b
- Initial Fedora Package
